-- CreateTable
CREATE TABLE `performancereport` (
    `reportID` INTEGER NOT NULL AUTO_INCREMENT,
    `studentID` INTEGER NOT NULL,
    `details` TEXT NOT NULL,

    INDEX `studentID`(`studentID`),
    PRIMARY KEY (`reportID`)
) DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- CreateTable
CREATE TABLE `practiceset` (
    `setID` INTEGER NOT NULL AUTO_INCREMENT,
    `studentID` INTEGER NOT NULL,

    INDEX `studentID`(`studentID`),
    PRIMARY KEY (`setID`)
) DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- CreateTable
CREATE TABLE `question` (
    `questionID` INTEGER NOT NULL AUTO_INCREMENT,
    `content` TEXT NOT NULL,
    `correctAnswer` VARCHAR(255) NOT NULL,
    `difficultyLevel` ENUM('High', 'Medium', 'Low') NOT NULL,
    `bloomsLevel` ENUM('remembering', 'understanding', 'applying') NOT NULL,
    `learningType` VARCHAR(255) NOT NULL,
    `graphicOrAnimation` VARCHAR(255) NULL,
    `subtopicID` INTEGER NOT NULL,

    INDEX `subtopicID`(`subtopicID`),
    PRIMARY KEY (`questionID`)
) DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- CreateTable
CREATE TABLE `response` (
    `responseID` INTEGER NOT NULL AUTO_INCREMENT,
    `questionID` INTEGER NOT NULL,
    `studentID` INTEGER NOT NULL,
    `answer` VARCHAR(255) NOT NULL,
    `timestamp` DATETIME(0) NOT NULL,

    INDEX `questionID`(`questionID`),
    INDEX `studentID`(`studentID`),
    PRIMARY KEY (`responseID`)
) DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- CreateTable
CREATE TABLE `student` (
    `studentID` INTEGER NOT NULL AUTO_INCREMENT,
    `username` VARCHAR(191) NOT NULL,
    `password` VARCHAR(255) NOT NULL,
    `learningStyle` ENUM('Visual', 'Auditory', 'Kinesthetic', 'Read/Write') NOT NULL,
    `mathematicalProficiency` ENUM('High', 'Medium', 'Low') NOT NULL,

    UNIQUE INDEX `student_username_key`(`username`),
    PRIMARY KEY (`studentID`)
) DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- CreateTable
CREATE TABLE `subtopic` (
    `subtopicID` INTEGER NOT NULL AUTO_INCREMENT,
    `name` VARCHAR(255) NOT NULL,
    `learningOutcomes` TEXT NOT NULL,
    `periods` INTEGER NOT NULL,

    PRIMARY KEY (`subtopicID`)
) DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- CreateTable
CREATE TABLE `teacher` (
    `teacherID` INTEGER NOT NULL AUTO_INCREMENT,
    `username` VARCHAR(255) NOT NULL,
    `password` VARCHAR(255) NOT NULL,

    PRIMARY KEY (`teacherID`)
) DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- AddForeignKey
ALTER TABLE `performancereport` ADD CONSTRAINT `performancereport_ibfk_1` FOREIGN KEY (`studentID`) REFERENCES `student`(`studentID`) ON DELETE CASCADE ON UPDATE NO ACTION;

-- AddForeignKey
ALTER TABLE `practiceset` ADD CONSTRAINT `practiceset_ibfk_1` FOREIGN KEY (`studentID`) REFERENCES `student`(`studentID`) ON DELETE CASCADE ON UPDATE NO ACTION;

-- AddForeignKey
ALTER TABLE `question` ADD CONSTRAINT `question_ibfk_1` FOREIGN KEY (`subtopicID`) REFERENCES `subtopic`(`subtopicID`) ON DELETE CASCADE ON UPDATE NO ACTION;

-- AddForeignKey
ALTER TABLE `response` ADD CONSTRAINT `response_ibfk_1` FOREIGN KEY (`questionID`) REFERENCES `question`(`questionID`) ON DELETE CASCADE ON UPDATE NO ACTION;

-- AddForeignKey
ALTER TABLE `response` ADD CONSTRAINT `response_ibfk_2` FOREIGN KEY (`studentID`) REFERENCES `student`(`studentID`) ON DELETE CASCADE ON UPDATE NO ACTION;
