// src/api.js
import axios from 'axios';

const API_URL = 'http://localhost:5000'; // Adjust this if your server runs on a different port

async function makeRequest(url, method, data) {
    try {
        const response = await axios({ url, method, data });
        return response.data;
    } catch (error) {
        if (error.response) {
            console.error('Response error:', error.response.data);
            throw new Error(error.response.data.message || 'Error with the request.');
        } else if (error.request) {
            console.error('Request error:', error.request);
            throw new Error('No response received.');
        } else {
            console.error('Setup error:', error.message);
            throw new Error(error.message);
        }
    }
}

export const registerStudent = (userData) => makeRequest(`${API_URL}/register/student`, 'post', userData);
export const loginStudent = (credentials) => makeRequest(`${API_URL}/login/student`, 'post', credentials);
export const registerTeacher = (userData) => makeRequest(`${API_URL}/register/teacher`, 'post', userData);
export const loginTeacher = (credentials) => makeRequest(`${API_URL}/login/teacher`, 'post', credentials);
export const testDbConnection = () => makeRequest(`${API_URL}/test-db`, 'get');

