// React core
import React, { useState, useEffect } from 'react';

// React Router DOM for routing
import { BrowserRouter as Router, Routes, Route, Navigate } from 'react-router-dom';

// Components
import Home from './Home';
import About from './About';
import Insights from './Insights';
import Navbar from './Navbar';
import LoginPage from './LoginPage';
import RegisterPage from './RegisterPage';

function App() {
  const [isLoggedIn, setIsLoggedIn] = useState(false);

  useEffect(() => {
    const token = localStorage.getItem('token');
    setIsLoggedIn(!!token);
  }, []);
 
  // Function to call when the registration is successful
 const onRegistrationSuccess = (token) => {
  localStorage.setItem('token', token); // Save the token to localStorage
  setIsLoggedIn(true); // Update the login state to true
};

  const handleLogout = () => {
    localStorage.removeItem('token');
    setIsLoggedIn(false);
  };

  const handleLoginSuccess = () => {
    setIsLoggedIn(true);
  };

  // const handleRegistrationSuccess = () => {
  //   setIsLoggedIn(true);
  // };

    

  return (
    <Router>
      <Navbar isLoggedIn={isLoggedIn} onLogout={handleLogout} />
      <Routes>
        <Route path="/login" element={
          !isLoggedIn ? (
            <LoginPage onLoginSuccess={handleLoginSuccess} />
          ) : (
            <Navigate replace to="/home" />
          )
        } />
        <Route path="/register" element={
          !isLoggedIn ? (
            <RegisterPage onRegistrationSuccess={onRegistrationSuccess} />
          ) : (
            <Navigate replace to="/home" />
          )
        } />
        <Route path="/about" element={isLoggedIn ? <About /> : <Navigate replace to="/login" />} />
        <Route path="/insights" element={isLoggedIn ? <Insights /> : <Navigate replace to="/login" />} />
        <Route path="/home" element={isLoggedIn ? <Home /> : <Navigate replace to="/login" />} />
        <Route path="/" element={<Navigate replace to={isLoggedIn ? "/home" : "/login"} />} />
        <Route path="*" element={<Navigate replace to={isLoggedIn ? "/home" : "/login"} />} />
      </Routes>
    </Router>
  );
}

export default App;
