// Navbar.js
import React from 'react';
import { NavLink, useNavigate } from 'react-router-dom';

const Navbar = ({ isLoggedIn, onLogout }) => {
  const navigate = useNavigate();

  const activeLinkStyle = ({ isActive }) =>
    isActive ? 'text-blue-500' : 'text-white';

  const logout = () => {
    // Clear the user token and any other relevant data
    localStorage.removeItem('token');
    
    // Call the onLogout prop to update the App state
    onLogout();

    // Redirect to the login page
    navigate('/login');
  };

  return (
    <nav className="bg-gray-800 p-4">
      <ul className="flex justify-between items-center space-x-4">
        <div className="flex space-x-4">
          <li>
            <NavLink to="/" className={activeLinkStyle} aria-label="Home">
              Home
            </NavLink>
          </li>
          <li>
            <NavLink to="/about" className={activeLinkStyle} aria-label="About">
              About
            </NavLink>
          </li>
          <li>
            <NavLink to="/insights" className={activeLinkStyle} aria-label="Insights">
              Insights
            </NavLink>
          </li>
        </div>
        {isLoggedIn && (
          <li>
            <button onClick={logout} className="text-white hover:text-red-500 transition duration-300">
              Logout
            </button>
          </li>
        )}
      </ul>
    </nav>
  );
};

export default Navbar;
